.. text2array documentation master file, created by
   sphinx=quickstart on Sun Feb  3 12:56:51 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to text2array's documentation!
======================================

*Convert your NLP text data to arrays!*

**text2array** helps you process your NLP text dataset into Numpy ndarray objects that are
ready to use for e.g. neural network inputs. **text2array** handles data shuffling,
batching, padding, and converting into arrays. Say goodbye to these tedious works!

.. toctree::
   :maxdepth: 2

   quickstart
   tutorial
   api

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
